@@ -3,6 +3,8 @@ sub dc_debconf_select (){
     my $class    = shift;
     my $priority = shift;
     my $question = "shared/packages-$class";
+    my @newchoices = ();
+    my @oldchoices = ();
 
     $priority = "critical" if not $priority;
     
@@ -15,19 +17,22 @@ sub dc_debconf_select (){
     my ($errorcode,$pkgowners) = metaget ($question, "owners");
     return if $errorcode;
     
-    my @choices = ();
     foreach (split (/\s*,\s*/, $pkgowners)){
 	my $entry = metaget ("$_/languages", "default");
 	for ( $entry ){ # trim leading/trailing whitespaces the perlfaq way
 	    s/^\s+//;
 	    s/\s+$//;
 	}
-	push (@choices, split(/\s*,\s*/, $entry));
+	push (@newchoices, split(/\s*,\s*/, $entry));
     }
-    my $choices = join (', ', sort {lc $a cmp lc $b} @choices);
+    my $choices = join (', ', sort {lc $a cmp lc $b} @newchoices);
 
     $question = "dictionaries-common/default-$class";
-    if ($choices ne metaget ($question, "choices")) {
+    @oldchoices = split(/\s*,\s*/,metaget ($question, "choices"));
+    pop @oldchoices;
+    my $oldchoices = join (', ', @oldchoices);
+#    print STDERR "**\nnew:$choices\nold:$oldchoices\n";
+    if ( $choices ne $oldchoices ) {
 	subst ($question, "choices", $choices);
 	fset ($question, "seen", "false");
     }
